==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "ลูกค้า"

, "State"
: ""

, "Role"
: "หน้าที่"

, "Source"
: "แหล่งข้อมูล"

, "Start"
: "เริ่มต้น"

, "Scheduled end"
: ""

, "End"
: "สิ้นสุด"

, "Turnover"
: ""

, "Probability"
: "ความน่าจะเป็น"

, "Folder"
: "แฟ้มเอกสาร"

, "Updated by"
: "อัพเดท โดย"

, "Updated Fields:"
: "เขตข้อมูลที่ทำการอัพเดท: "

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "ป้ายกำกับ"

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: "ข้อมูลที่ดำเนินการ"

, "Leadstate"
: "สถานะดำเนินการ"

, "Leadtype"
: "ประเภทดำเนินการ"

, "Leadsource"
: "แหล่งดำเนินการ"

, "End Scheduled"
: ""

, "Contacts"
: "การติดต่อ"

, "Address"
: "ที่อยู่"

, "Telephone"
: "โทรศัพท์"

, "Email"
: "อีเมล"

, "Tasks"
: "หน้าที่"

, "Due Date"
: "วันครบกำหนด"

, "Priority"
: "ลำดับความสำคัญ"

, "Products"
: "สินค้า"

, "low"
: "ต่ำ"

, "normal"
: "ธรรมดา"

, "high"
: "สูง"

, "urgent"
: "ด่วน"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: "ปรับปรุงครั้งล่าสุด โดยฉัน"

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: "ได้อีเมลแจ้งเตือน"

, "The level of actions you want to be notified about."
: "ระดับของการกระทำที่คุณต้องการรับทราบ"

, "Send Notifications Emails for own actions"
: "ส่งอีเมลแจ้งเตือนของการกระทำของตัวเอง"

, "Get notifications emails for actions you did yourself"
: "ได้อีเมลแจ้งเตือนสำหรับสิ่งที่คุณได้ทำด้วยตัวคุณเอง"

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "ค่าที่ชอบหลัก"

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Contact"
: "การติดต่อ"

, "CRM Role"
: "หน้าที่ CRM"

, "Lead, Leads"
: [
  ""

]
, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "Lead name"
: ""

, "Last Modified Time"
: "เวลาที่ปรับปรุงครั้งล่าสุด"

, "Last Modified By"
: "ปรับปรุงครั้งล่าสุด โดย"

, "Creation Time"
: "เวลาที่สร้างขึ้น"

, "Created By"
: "สร้าง โดย"

, "Estimated end"
: ""

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "คู่หู"

, "Phone"
: "โทรศัพท์"

, "Mobile"
: "โทรศัพท์เคลื่อนที่"

, "Fax"
: "โทรสาร"

, "E-Mail"
: "อีเมล"

, "Web"
: "เวบไซด์"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "สถานะ"

, "Change type to Customer"
: "เปลี่ยน ประเภทลูกค้า"

, "Responsible"
: "รับผิดชอบ"

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: "เปลี่ยนประเภทการติดต่อ"

, "Search for Contacts to add ..."
: "ค้นหาการติดต่อเพื่อเพิ่ม ..."

, "Name"
: "ชื่อ"

, "Data"
: "ข้อมูล"

, "Cellphone"
: "โทรศัพท์เคลื่อนที่"

, "Add new {0}"
: "เพิ่ม {0} ใหม่"

, "Unlink {0}"
: "ยกเลิกการเชื่อมต่อ {0}"

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "แก้ไข {0}"

, "Edit selected {0}"
: "แก้ไข {0} ที่เลือก"

, "No Tasks to display"
: "ไม่มีหน้าที่ให้แสดง"

, "Summary"
: "ข้อสรุป"

, "Add a task..."
: "เพิ่มหน้าที่..."

, "Percent"
: "เปอร์เซนต์"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: "เลือก หน้าที่"

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "การอธิบาย"

, "Enter description"
: "ใส่ คำอธิบาย"

, "New Lead"
: ""

, "Product"
: "สินค้า"

, "Price"
: "ราคา"

, "Quantity"
: "จำนวน"

, "Search for Products to add ..."
: "ค้นหาสินค้าเพื่อเพิ่ม ..."

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: "หน้าที่"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "เปิด"

, "contacted"
: "ได้ติดต่อแล้ว"

, "waiting for feedback"
: "กำลังรอผลตอบรับ"

, "quote sent"
: ""

, "accepted"
: "ได้ยอมรับแล้ว"

, "lost"
: "หาย"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "ตัวแทนจำหน่าย"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "ระดับของการกระทำที่คุณต้องการรับทราบ"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "ค่าที่ชอบหลัก"

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: "ป้ายกำกับ"

, "Lead name"
: ""

, "Responsible"
: "รับผิดชอบ"

, "Partner"
: "คู่หู"

, "Customer"
: "ลูกค้า"

, "Leadstate"
: "สถานะดำเนินการ"

, "Leadtype"
: "ประเภทดำเนินการ"

, "Leadsource"
: "แหล่งดำเนินการ"

, "Probability"
: "ความน่าจะเป็น"

, "Turnover"
: ""

, "Estimated end"
: ""

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "การติดต่อ"

, "CRM Role"
: "หน้าที่ CRM"

, "Tasks"
: "หน้าที่"

, "No Tasks to display"
: "ไม่มีหน้าที่ให้แสดง"

, "Summary"
: "ข้อสรุป"

, "Add a task..."
: "เพิ่มหน้าที่..."

, "Due Date"
: "วันครบกำหนด"

, "Priority"
: "ลำดับความสำคัญ"

, "Percent"
: "เปอร์เซนต์"

, "Status"
: "สถานะ"

, "Organizer"
: ""

, "Add new {0}"
: "เพิ่ม {0} ใหม่"

, "Unlink {0}"
: "ยกเลิกการเชื่อมต่อ {0}"

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "แก้ไข {0}"

, "Edit selected {0}"
: "แก้ไข {0} ที่เลือก"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""

]
, "Select Lead"
: ""

, "Role"
: "หน้าที่"

, "Select Role"
: "เลือก หน้าที่"

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "โทรศัพท์"

, "Mobile"
: "โทรศัพท์เคลื่อนที่"

, "Fax"
: "โทรสาร"

, "E-Mail"
: "อีเมล"

, "Web"
: "เวบไซด์"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "เริ่มต้น"

, "Change type to Customer"
: "เปลี่ยน ประเภทลูกค้า"

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: "เปลี่ยนประเภทการติดต่อ"

, "Search for Contacts to add ..."
: "ค้นหาการติดต่อเพื่อเพิ่ม ..."

, "Name"
: "ชื่อ"

, "Address"
: "ที่อยู่"

, "Data"
: "ข้อมูล"

, "Cellphone"
: "โทรศัพท์เคลื่อนที่"

, "End"
: "สิ้นสุด"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "สินค้า"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "การอธิบาย"

, "Enter description"
: "ใส่ คำอธิบาย"

, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "Last Modified Time"
: "เวลาที่ปรับปรุงครั้งล่าสุด"

, "Last Modified By"
: "ปรับปรุงครั้งล่าสุด โดย"

, "Creation Time"
: "เวลาที่สร้างขึ้น"

, "Created By"
: "สร้าง โดย"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "สินค้า"

, "Price"
: "ราคา"

, "Quantity"
: "จำนวน"

, "Search for Products to add ..."
: "ค้นหาสินค้าเพื่อเพิ่ม ..."

, "All leads I have read grants for"
: ""

, "Last modified by me"
: "ปรับปรุงครั้งล่าสุด โดยฉัน"

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "เปิด"

, "contacted"
: "ได้ติดต่อแล้ว"

, "waiting for feedback"
: "กำลังรอผลตอบรับ"

, "quote sent"
: ""

, "accepted"
: "ได้ยอมรับแล้ว"

, "lost"
: "หาย"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "ตัวแทนจำหน่าย"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: ""

, "Source"
: "แหล่งข้อมูล"

, "Scheduled end"
: ""

, "Folder"
: "แฟ้มเอกสาร"

, "Updated by"
: "อัพเดท โดย"

, "Updated Fields:"
: "เขตข้อมูลที่ทำการอัพเดท: "

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: "หน้าที่"

, "Lead Data"
: "ข้อมูลที่ดำเนินการ"

, "End Scheduled"
: ""

, "Contacts"
: "การติดต่อ"

, "Telephone"
: "โทรศัพท์"

, "Email"
: "อีเมล"

, "low"
: "ต่ำ"

, "normal"
: "ธรรมดา"

, "high"
: "สูง"

, "urgent"
: "ด่วน"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""




, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
